# Quickstart adon

Start by calling `yo sin:adon`, which will quickly scaffold all the files needed for your adon, including the beginnings of a test.

```shell
yo sin:adon
```

Respond to the questions, especially choosing an adonName.

This quickstart will assume you chose the name `Jezebel`.

What yeoman generator produces follows **adon** s _pattern_ which is as follows:

## Files Created/Affected

```shell
project
│   index.html
│   ...
│
└───js
│   │   main.js
│   │   ...
│   │
│   └───adon
│       │   adonJezebel.js
│       │   ...
│       
└───stylesheets
│   │
│   └───adon
│       │   adonJezebel.scss
│       │   ...
│       
└───test
    │
    └───adon
        │-- adonJezebel.js
        │   ...
```

## Edits required to implement an adon such as Jezebel

### index.html

Manually add:

```html
index.html
<!-- YourApp/index.html -->
<script src="js/adon/adonJezebel.js"></script>
<!-- add before this tag
<script src="js/main.js"></script> -->
```

### js/main.js

Manually add:

```javascript
// js/main.js
$(document).ready(function() {
  $("aside").adonJezebel(true);
});
```

This will run your _adon_, a jQuery prototype, against _believers_.

### js/adon/adonJezebel.js

Code functionality into `js/adon/adonJezebel.js` where `yo sin:adon` starts you off with this:

```javascript
// js/adon/adonJezebel.js
// NB: Twinned with /stylesheets/adon/adonJezebel.js
// NB: Tested by /test/adon/adonJezebel.js
jQuery.fn.extend({
  adonJezebel: function() {
    return this.each(function() {
      var $tag = jQuery(this);
      $tag.addClass("adonJezebel");
      return $tag;
    });
  },
  _adofJezebel: function() {
    return this.each(function() {
      var $tag = jQuery(this);
      $tag.removeClass("adonJezebel");
      return $tag;
    });
  }
});
```

Calling `$("aside").adonJezebel(true);` runs the first function, so now we can expect all `aside` tags to have the `.adonJezebel` className.

And you can easily interact with the event model like this:

```javascript
// js/adon/adonJezebel.js
$tag.click(function() {
  // turning off HotPink when the object is clicked.
  $tag._adofJezebel();
});
/* added before the line
            $tag.addClass("adonJezebel") */
```

Which will instruction the _adon_ to call the `_adofJezebel` function and remove the className `.adonJezebel` when the user clicks the object.

### stylesheets/adon/adonJezebel.scss

Add styles which your code can activate in `stylesheets/adon/adonJezebel.scss` where `yo sin:adon` does most of this work for you:

```scss
// stylesheets/adon/adonJezebel.scss
.adonJezebel {
  // DEBUG: Twinned with /js/adon/adonJezebel.js
  // turning ON HotPink when the adon applies class to the tag.
  color: HotPink !important;
  border: HotPink 1px solid !important;
}
```

By adding and removing the `.adonJezebel` from the `aside` tagName, the _adon_ is simply turning the element "HotPink" and back.

### test/adon/adonJezebel.js

We will cover testing adons in a tutorial.

- [Testing adons](tutorial-testing-adons.md)
